@@ -33,4 +33,15 @@ is_handler <- function(x){
 
 assertthat::on_failure(is_handler) <- function(call, env){
   paste("`handler` must be a function that accepts: `req`, and `res`")
-}
\ No newline at end of file
+}
+
+is_logger <- function(x){
+  inherits(x, "Logger")
+}
+
+assertthat::on_failure(is_logger) <- function(call, env){
+  sprintf(
+    "%s must be an object of class `Logger` from the `log` package",
+    deparse(call$x)
+  )
+}
